@@ -1,9 +1,11 @@
 #!/usr/bin/python
 # -*- coding: utf8 -*-
+from flask import request
 
 from mobio.libs.validator import HttpValidator, VALIDATION_RESULT
 
 from src.common import LANG
+from src.common.lang_config import LANG_VI, LangConfig, LANG_EN
 from src.common.mobio_exception import ParamInvalidError
 
 
@@ -32,4 +34,11 @@ class BaseController(object):
             raise ParamInvalidError(LANG.MUST_NOT_EMPTY, param_name)
 
     def __init__(self):
-        pass
\ No newline at end of file
+        try:
+            param = request.args.get('lang')
+            if param and param not in (LANG_VI, LANG_EN):
+                raise ParamInvalidError(LANG.LANG_ERROR)
+            self.lang = LangConfig().lang_map(param)
+        except:
+            param = None
+        self.language = param or LANG_VI
